'use client';

import { useState, useMemo } from 'react';
import { Button } from '@/components/ui/button';
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { Input } from '@/components/ui/input';
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from '@/components/ui/select';

const listings = [
  {
    id: 1,
    title: 'Data Structures Textbook',
    description: 'Used textbook for CS course, in good condition.',
    category: 'textbooks',
    posted: '2 days ago',
  },
  {
    id: 2,
    title: 'iPhone 12',
    description: 'Used iPhone 12, no scratches, fully functional.',
    category: 'electronics',
    posted: '1 day ago',
  },
  {
    id: 3,
    title: 'Winter Jacket',
    description: 'Warm jacket, perfect for winter.',
    category: 'clothing',
    posted: '3 days ago',
  },
  {
    id: 4,
    title: 'Study Table',
    description: 'Wooden study table, barely used.',
    category: 'furniture',
    posted: '5 days ago',
  },
  {
    id: 5,
    title: 'Laptop Charger',
    description: 'Original Dell laptop charger.',
    category: 'electronics',
    posted: '4 days ago',
  },
  {
    id: 6,
    title: 'Operating Systems Textbook',
    description: 'OS textbook for CS class.',
    category: 'textbooks',
    posted: '2 days ago',
  },
];

export default function ExplorePage() {
  const [searchTerm, setSearchTerm] = useState('');
  const [selectedCategory, setSelectedCategory] = useState('');

  const filteredListings = useMemo(() => {
    return listings.filter((item) => {
      const matchesSearch = item.title
        .toLowerCase()
        .includes(searchTerm.toLowerCase());
      const matchesCategory = selectedCategory
        ? item.category === selectedCategory
        : true;
      return matchesSearch && matchesCategory;
    });
  }, [searchTerm, selectedCategory]);

  return (
    <div className='container mx-auto px-4 py-8'>
      <h1 className='text-4xl font-bold mb-8'>Explore Listings</h1>

      <div className='flex flex-col md:flex-row gap-4 mb-8'>
        <Input
          className='md:w-1/3'
          placeholder='Search listings...'
          value={searchTerm}
          onChange={(e) => setSearchTerm(e.target.value)}
        />
        <Select onValueChange={(value) => setSelectedCategory(value)}>
          <SelectTrigger className='md:w-1/4'>
            <SelectValue placeholder='Category' />
          </SelectTrigger>
          <SelectContent>
            <SelectItem value='textbooks'>Textbooks</SelectItem>
            <SelectItem value='electronics'>Electronics</SelectItem>
            <SelectItem value='clothing'>Clothing</SelectItem>
            <SelectItem value='furniture'>Furniture</SelectItem>
          </SelectContent>
        </Select>
        <Button onClick={() => {}}>Search</Button>
      </div>

      {filteredListings.length > 0 ? (
        <div className='grid gap-6 md:grid-cols-2 lg:grid-cols-3'>
          {filteredListings.map((item) => (
            <Card key={item.id}>
              <CardHeader>
                <CardTitle>{item.title}</CardTitle>
                <CardDescription>
                  {item.category.charAt(0).toUpperCase() +
                    item.category.slice(1)}{' '}
                  • Posted {item.posted}
                </CardDescription>
              </CardHeader>
              <CardContent>
                <p>{item.description}</p>
              </CardContent>
              <CardFooter>
                <Button>View Details</Button>
              </CardFooter>
            </Card>
          ))}
        </div>
      ) : (
        <p>No listings found.</p>
      )}
    </div>
  );
}
