'use client';

import { AArrowDown, AArrowUp, ALargeSmall, Languages } from 'lucide-react';

import Container from '@/components/ui/container';
import {
  Select,
  SelectContent,
  SelectGroup,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from '@/components/ui/select';
import { Label } from '@/components/ui/label';
import { Switch } from '@/components/ui/switch';
import { Button } from '@/components/ui/button';
import { useAccessibility } from '@/contexts/accessibility-context';
import { useState, useEffect } from 'react';

export default function Accessibility() {
  const {
    highContrast,
    toggleHighContrast,
    increaseTextSize,
    decreaseTextSize,
    resetTextSize,
  } = useAccessibility();

  const [language, setLanguage] = useState('english');

  const [isHighContrast, setIsHighContrast] = useState(false);

  useEffect(() => {
    setIsHighContrast(highContrast);
  }, [highContrast]);

  const handleLanguageChange = (value: string) => {
    setLanguage(value);
  };

  return (
    <div className='bg-yellow-100 border-b border-zinc-30'>
      <Container className='py-4 justify-between hidden md:flex'>
        <div className='flex items-center gap-x-2'>
          <Languages className='text-black' />
          <Select
            defaultValue='english'
            value={language}
            onValueChange={handleLanguageChange}
          >
            <SelectTrigger className='w-[180px] font-medium border-black text-black'>
              <SelectValue />
            </SelectTrigger>
            <SelectContent className='font-medium'>
              <SelectGroup>
                <SelectItem value='english'>English</SelectItem>
                <SelectItem value='french'>French</SelectItem>
                <SelectItem value='german'>German</SelectItem>
                <SelectItem value='arabic'>Arabic</SelectItem>
                <SelectItem value='spanish'>Spanish</SelectItem>
              </SelectGroup>
            </SelectContent>
          </Select>
        </div>

        <div className='flex items-center space-x-2'>
          <Switch
            id='high-contrast-mode'
            checked={isHighContrast}
            onCheckedChange={() => {
              toggleHighContrast();
            }}
          />
          <Label
            htmlFor='high-contrast-mode'
            className='font-medium text-black'
          >
            High Contrast
          </Label>
        </div>

        <div className='flex gap-x-2'>
          <Button
            variant='outline'
            size='icon'
            className='border-muted-foreground'
            onClick={decreaseTextSize}
            aria-label='Decrease text size'
          >
            <AArrowDown />
          </Button>
          <Button
            variant='outline'
            size='icon'
            className='border-muted-foreground'
            onClick={resetTextSize}
            aria-label='Reset text size'
          >
            <ALargeSmall />
          </Button>
          <Button
            variant='outline'
            size='icon'
            className='border-muted-foreground'
            onClick={increaseTextSize}
            aria-label='Increase text size'
          >
            <AArrowUp />
          </Button>
        </div>
      </Container>
    </div>
  );
}
